@@ -4,27 +4,26 @@ import typing as t
 
 from sqlglot import exp, generator, parser, tokens, transforms
 from sqlglot.dialects.dialect import (
+    DATE_ADD_OR_SUB,
     Dialect,
     NormalizationStrategy,
     binary_from_function,
+    build_date_delta,
     build_formatted_time,
+    build_timetostr_or_tochar,
+    build_trunc,
     groupconcat_sql,
+    no_last_day_sql,
     rename_func,
     strposition_sql,
     timestrtotime_sql,
     timestamptrunc_sql,
-    build_date_delta,
-    no_last_day_sql,
-    DATE_ADD_OR_SUB,
 )
 from sqlglot.generator import unsupported_args
 from sqlglot.helper import seq_get
 from sqlglot.tokens import TokenType
 from sqlglot.optimizer.scope import build_scope
 
-if t.TYPE_CHECKING:
-    from sqlglot.dialects.dialect import DialectType
-
 
 def _sha2_sql(self: Exasol.Generator, expression: exp.SHA2) -> str:
     length = expression.text("length")
@@ -42,25 +41,6 @@ def _date_diff_sql(self: Exasol.Generator, expression: exp.DateDiff | exp.TsOrDs
     return self.func(f"{unit}S_BETWEEN", expression.this, expression.expression)
 
 
-# https://docs.exasol.com/db/latest/sql_references/functions/alphabeticallistfunctions/trunc%5Bate%5D%20(datetime).htm
-# https://docs.exasol.com/db/latest/sql_references/functions/alphabeticallistfunctions/trunc%5Bate%5D%20(number).htm
-def _build_trunc(args: t.List[exp.Expression], dialect: DialectType) -> exp.Expression:
-    first, second = seq_get(args, 0), seq_get(args, 1)
-
-    if not first or not second:
-        return exp.Anonymous(this="TRUNC", expressions=args)
-
-    if not first.type:
-        from sqlglot.optimizer.annotate_types import annotate_types
-
-        first = annotate_types(first, dialect=dialect)
-
-    if first.is_type(exp.DataType.Type.DATE, exp.DataType.Type.TIMESTAMP) and second.is_string:
-        return exp.DateTrunc(this=first, unit=second)
-
-    return exp.Anonymous(this="TRUNC", expressions=args)
-
-
 # https://docs.exasol.com/db/latest/sql_references/functions/alphabeticallistfunctions/zeroifnull.htm
 def _build_zeroifnull(args: t.List) -> exp.If:
     cond = exp.Is(this=seq_get(args, 0), expression=exp.Null())
@@ -319,6 +299,7 @@ class Exasol(Dialect):
             "ENDIF": TokenType.END,
             "LONG VARCHAR": TokenType.TEXT,
             "SEPARATOR": TokenType.SEPARATOR,
+            "SYSTIMESTAMP": TokenType.SYSTIMESTAMP,
         }
         KEYWORDS.pop("DIV")
 
@@ -333,12 +314,21 @@ class Exasol(Dialect):
                 f"{unit}S_BETWEEN": build_date_delta(exp.DateDiff, default_unit=unit)
                 for unit in DATE_UNITS
             },
+            "APPROXIMATE_COUNT_DISTINCT": exp.ApproxDistinct.from_arg_list,
             "BIT_AND": binary_from_function(exp.BitwiseAnd),
             "BIT_OR": binary_from_function(exp.BitwiseOr),
             "BIT_XOR": binary_from_function(exp.BitwiseXor),
             "BIT_NOT": lambda args: exp.BitwiseNot(this=seq_get(args, 0)),
             "BIT_LSHIFT": binary_from_function(exp.BitwiseLeftShift),
             "BIT_RSHIFT": binary_from_function(exp.BitwiseRightShift),
+            # https://docs.exasol.com/db/latest/sql_references/functions/alphabeticallistfunctions/convert_tz.htm
+            "CONVERT_TZ": lambda args: exp.ConvertTimezone(
+                source_tz=seq_get(args, 1),
+                target_tz=seq_get(args, 2),
+                timestamp=seq_get(args, 0),
+                options=seq_get(args, 3),
+            ),
+            "CURDATE": exp.CurrentDate.from_arg_list,
             # https://docs.exasol.com/db/latest/sql_references/functions/alphabeticallistfunctions/date_trunc.htm#DATE_TRUNC
             "DATE_TRUNC": lambda args: exp.TimestampTrunc(
                 this=seq_get(args, 1), unit=seq_get(args, 0)
@@ -350,6 +340,14 @@ class Exasol(Dialect):
             "HASH_SHA1": exp.SHA.from_arg_list,
             "HASH_MD5": exp.MD5.from_arg_list,
             "HASHTYPE_MD5": exp.MD5Digest.from_arg_list,
+            "HASH_SHA256": lambda args: exp.SHA2(
+                this=seq_get(args, 0), length=exp.Literal.number(256)
+            ),
+            "HASH_SHA512": lambda args: exp.SHA2(
+                this=seq_get(args, 0), length=exp.Literal.number(512)
+            ),
+            "NOW": exp.CurrentTimestamp.from_arg_list,
+            "NULLIFZERO": _build_nullifzero,
             "REGEXP_SUBSTR": exp.RegexpExtract.from_arg_list,
             "REGEXP_REPLACE": lambda args: exp.RegexpReplace(
                 this=seq_get(args, 0),
@@ -358,26 +356,12 @@ class Exasol(Dialect):
                 position=seq_get(args, 3),
                 occurrence=seq_get(args, 4),
             ),
-            "HASH_SHA256": lambda args: exp.SHA2(
-                this=seq_get(args, 0), length=exp.Literal.number(256)
-            ),
-            "HASH_SHA512": lambda args: exp.SHA2(
-                this=seq_get(args, 0), length=exp.Literal.number(512)
-            ),
-            "TRUNC": _build_trunc,
-            "TRUNCATE": _build_trunc,
-            "VAR_POP": exp.VariancePop.from_arg_list,
-            "APPROXIMATE_COUNT_DISTINCT": exp.ApproxDistinct.from_arg_list,
-            "TO_CHAR": build_formatted_time(exp.ToChar, "exasol"),
+            "TRUNC": build_trunc,
+            "TRUNCATE": build_trunc,
+            "TO_CHAR": build_timetostr_or_tochar,
             "TO_DATE": build_formatted_time(exp.TsOrDsToDate, "exasol"),
-            # https://docs.exasol.com/db/latest/sql_references/functions/alphabeticallistfunctions/convert_tz.htm
-            "CONVERT_TZ": lambda args: exp.ConvertTimezone(
-                source_tz=seq_get(args, 1),
-                target_tz=seq_get(args, 2),
-                timestamp=seq_get(args, 0),
-                options=seq_get(args, 3),
-            ),
-            "NULLIFZERO": _build_nullifzero,
+            "USER": exp.CurrentUser.from_arg_list,
+            "VAR_POP": exp.VariancePop.from_arg_list,
             "ZEROIFNULL": _build_zeroifnull,
         }
         CONSTRAINT_PARSERS = {
@@ -387,11 +371,25 @@ class Exasol(Dialect):
                 this=self._match(TokenType.IS) and self._parse_string(),
             ),
         }
+
+        FUNC_TOKENS = {
+            *parser.Parser.FUNC_TOKENS,
+            TokenType.SYSTIMESTAMP,
+        }
+
+        NO_PAREN_FUNCTIONS = {
+            **parser.Parser.NO_PAREN_FUNCTIONS,
+            TokenType.SYSTIMESTAMP: exp.Systimestamp,
+            TokenType.CURRENT_SCHEMA: exp.CurrentSchema,
+        }
+
         FUNCTION_PARSERS = {
             **parser.Parser.FUNCTION_PARSERS,
             # https://docs.exasol.com/db/latest/sql_references/functions/alphabeticallistfunctions/listagg.htm
             # https://docs.exasol.com/db/latest/sql_references/functions/alphabeticallistfunctions/group_concat.htm
             **dict.fromkeys(("GROUP_CONCAT", "LISTAGG"), lambda self: self._parse_group_concat()),
+            # https://docs.exasol.com/db/latest/sql_references/functions/alphabeticallistfunctions/json_value.htm
+            "JSON_VALUE": lambda self: self._parse_json_value(),
         }
 
         def _parse_column(self) -> t.Optional[exp.Expression]:
@@ -438,6 +436,9 @@ class Exasol(Dialect):
             exp.DataType.Type.DECIMAL128: "DECIMAL",
             exp.DataType.Type.DECIMAL256: "DECIMAL",
             exp.DataType.Type.DATETIME: "TIMESTAMP",
+            exp.DataType.Type.TIMESTAMPTZ: "TIMESTAMP",
+            exp.DataType.Type.TIMESTAMPLTZ: "TIMESTAMP",
+            exp.DataType.Type.TIMESTAMPNTZ: "TIMESTAMP",
         }
 
         def datatype_sql(self, expression: exp.DataType) -> str:
@@ -464,6 +465,7 @@ class Exasol(Dialect):
             exp.BitwiseRightShift: rename_func("BIT_RSHIFT"),
             # https://docs.exasol.com/db/latest/sql_references/functions/alphabeticallistfunctions/bit_xor.htm
             exp.BitwiseXor: rename_func("BIT_XOR"),
+            exp.CurrentSchema: lambda *_: "CURRENT_SCHEMA",
             exp.DateDiff: _date_diff_sql,
             exp.DateAdd: _add_date_sql,
             exp.TsOrDsAdd: _add_date_sql,
@@ -483,6 +485,10 @@ class Exasol(Dialect):
             ),
             # https://docs.exasol.com/db/latest/sql_references/functions/alphabeticallistfunctions/mod.htm
             exp.Mod: rename_func("MOD"),
+            # https://docs.exasol.com/db/latest/sql_references/functions/alphabeticallistfunctions/rank.htm
+            exp.Rank: unsupported_args("expressions")(lambda *_: "RANK()"),
+            # https://docs.exasol.com/db/latest/sql_references/functions/alphabeticallistfunctions/dense_rank.htm
+            exp.DenseRank: unsupported_args("expressions")(lambda *_: "DENSE_RANK()"),
             # https://docs.exasol.com/db/latest/sql_references/functions/alphabeticallistfunctions/regexp_substr.htm
             exp.RegexpExtract: unsupported_args("parameters", "group")(
                 rename_func("REGEXP_SUBSTR")
@@ -542,6 +548,475 @@ class Exasol(Dialect):
             exp.LastDay: no_last_day_sql,
         }
 
+        # https://docs.exasol.com/db/7.1/sql_references/system_tables/metadata/exa_sql_keywords.htm
+        RESERVED_KEYWORDS = {
+            "absolute",
+            "action",
+            "add",
+            "after",
+            "all",
+            "allocate",
+            "alter",
+            "and",
+            "any",
+            "append",
+            "are",
+            "array",
+            "as",
+            "asc",
+            "asensitive",
+            "assertion",
+            "at",
+            "attribute",
+            "authid",
+            "authorization",
+            "before",
+            "begin",
+            "between",
+            "bigint",
+            "binary",
+            "bit",
+            "blob",
+            "blocked",
+            "bool",
+            "boolean",
+            "both",
+            "by",
+            "byte",
+            "call",
+            "called",
+            "cardinality",
+            "cascade",
+            "cascaded",
+            "case",
+            "casespecific",
+            "cast",
+            "catalog",
+            "chain",
+            "char",
+            "character",
+            "character_set_catalog",
+            "character_set_name",
+            "character_set_schema",
+            "characteristics",
+            "check",
+            "checked",
+            "clob",
+            "close",
+            "coalesce",
+            "collate",
+            "collation",
+            "collation_catalog",
+            "collation_name",
+            "collation_schema",
+            "column",
+            "commit",
+            "condition",
+            "connect_by_iscycle",
+            "connect_by_isleaf",
+            "connect_by_root",
+            "connection",
+            "constant",
+            "constraint",
+            "constraint_state_default",
+            "constraints",
+            "constructor",
+            "contains",
+            "continue",
+            "control",
+            "convert",
+            "corresponding",
+            "create",
+            "cs",
+            "csv",
+            "cube",
+            "current",
+            "current_cluster",
+            "current_cluster_uid",
+            "current_date",
+            "current_path",
+            "current_role",
+            "current_schema",
+            "current_session",
+            "current_statement",
+            "current_time",
+            "current_timestamp",
+            "current_user",
+            "cursor",
+            "cycle",
+            "data",
+            "datalink",
+            "datetime_interval_code",
+            "datetime_interval_precision",
+            "day",
+            "dbtimezone",
+            "deallocate",
+            "dec",
+            "decimal",
+            "declare",
+            "default",
+            "default_like_escape_character",
+            "deferrable",
+            "deferred",
+            "defined",
+            "definer",
+            "delete",
+            "deref",
+            "derived",
+            "desc",
+            "describe",
+            "descriptor",
+            "deterministic",
+            "disable",
+            "disabled",
+            "disconnect",
+            "dispatch",
+            "distinct",
+            "dlurlcomplete",
+            "dlurlpath",
+            "dlurlpathonly",
+            "dlurlscheme",
+            "dlurlserver",
+            "dlvalue",
+            "do",
+            "domain",
+            "double",
+            "drop",
+            "dynamic",
+            "dynamic_function",
+            "dynamic_function_code",
+            "each",
+            "else",
+            "elseif",
+            "elsif",
+            "emits",
+            "enable",
+            "enabled",
+            "end",
+            "end-exec",
+            "endif",
+            "enforce",
+            "equals",
+            "errors",
+            "escape",
+            "except",
+            "exception",
+            "exec",
+            "execute",
+            "exists",
+            "exit",
+            "export",
+            "external",
+            "extract",
+            "false",
+            "fbv",
+            "fetch",
+            "file",
+            "final",
+            "first",
+            "float",
+            "following",
+            "for",
+            "forall",
+            "force",
+            "format",
+            "found",
+            "free",
+            "from",
+            "fs",
+            "full",
+            "function",
+            "general",
+            "generated",
+            "geometry",
+            "get",
+            "global",
+            "go",
+            "goto",
+            "grant",
+            "granted",
+            "group",
+            "group_concat",
+            "grouping",
+            "groups",
+            "hashtype",
+            "hashtype_format",
+            "having",
+            "high",
+            "hold",
+            "hour",
+            "identity",
+            "if",
+            "ifnull",
+            "immediate",
+            "impersonate",
+            "implementation",
+            "import",
+            "in",
+            "index",
+            "indicator",
+            "inner",
+            "inout",
+            "input",
+            "insensitive",
+            "insert",
+            "instance",
+            "instantiable",
+            "int",
+            "integer",
+            "integrity",
+            "intersect",
+            "interval",
+            "into",
+            "inverse",
+            "invoker",
+            "is",
+            "iterate",
+            "join",
+            "key_member",
+            "key_type",
+            "large",
+            "last",
+            "lateral",
+            "ldap",
+            "leading",
+            "leave",
+            "left",
+            "level",
+            "like",
+            "limit",
+            "listagg",
+            "localtime",
+            "localtimestamp",
+            "locator",
+            "log",
+            "longvarchar",
+            "loop",
+            "low",
+            "map",
+            "match",
+            "matched",
+            "merge",
+            "method",
+            "minus",
+            "minute",
+            "mod",
+            "modifies",
+            "modify",
+            "module",
+            "month",
+            "names",
+            "national",
+            "natural",
+            "nchar",
+            "nclob",
+            "new",
+            "next",
+            "nls_date_format",
+            "nls_date_language",
+            "nls_first_day_of_week",
+            "nls_numeric_characters",
+            "nls_timestamp_format",
+            "no",
+            "nocycle",
+            "nologging",
+            "none",
+            "not",
+            "null",
+            "nullif",
+            "number",
+            "numeric",
+            "nvarchar",
+            "nvarchar2",
+            "object",
+            "of",
+            "off",
+            "old",
+            "on",
+            "only",
+            "open",
+            "option",
+            "options",
+            "or",
+            "order",
+            "ordering",
+            "ordinality",
+            "others",
+            "out",
+            "outer",
+            "output",
+            "over",
+            "overlaps",
+            "overlay",
+            "overriding",
+            "pad",
+            "parallel_enable",
+            "parameter",
+            "parameter_specific_catalog",
+            "parameter_specific_name",
+            "parameter_specific_schema",
+            "parquet",
+            "partial",
+            "path",
+            "permission",
+            "placing",
+            "plus",
+            "preceding",
+            "preferring",
+            "prepare",
+            "preserve",
+            "prior",
+            "privileges",
+            "procedure",
+            "profile",
+            "qualify",
+            "random",
+            "range",
+            "read",
+            "reads",
+            "real",
+            "recovery",
+            "recursive",
+            "ref",
+            "references",
+            "referencing",
+            "refresh",
+            "regexp_like",
+            "relative",
+            "release",
+            "rename",
+            "repeat",
+            "replace",
+            "restore",
+            "restrict",
+            "result",
+            "return",
+            "returned_length",
+            "returned_octet_length",
+            "returns",
+            "revoke",
+            "right",
+            "rollback",
+            "rollup",
+            "routine",
+            "row",
+            "rows",
+            "rowtype",
+            "savepoint",
+            "schema",
+            "scope",
+            "scope_user",
+            "script",
+            "scroll",
+            "search",
+            "second",
+            "section",
+            "security",
+            "select",
+            "selective",
+            "self",
+            "sensitive",
+            "separator",
+            "sequence",
+            "session",
+            "session_user",
+            "sessiontimezone",
+            "set",
+            "sets",
+            "shortint",
+            "similar",
+            "smallint",
+            "some",
+            "source",
+            "space",
+            "specific",
+            "specifictype",
+            "sql",
+            "sql_bigint",
+            "sql_bit",
+            "sql_char",
+            "sql_date",
+            "sql_decimal",
+            "sql_double",
+            "sql_float",
+            "sql_integer",
+            "sql_longvarchar",
+            "sql_numeric",
+            "sql_preprocessor_script",
+            "sql_real",
+            "sql_smallint",
+            "sql_timestamp",
+            "sql_tinyint",
+            "sql_type_date",
+            "sql_type_timestamp",
+            "sql_varchar",
+            "sqlexception",
+            "sqlstate",
+            "sqlwarning",
+            "start",
+            "state",
+            "statement",
+            "static",
+            "structure",
+            "style",
+            "substring",
+            "subtype",
+            "sysdate",
+            "system",
+            "system_user",
+            "systimestamp",
+            "table",
+            "temporary",
+            "text",
+            "then",
+            "time",
+            "timestamp",
+            "timezone_hour",
+            "timezone_minute",
+            "tinyint",
+            "to",
+            "trailing",
+            "transaction",
+            "transform",
+            "transforms",
+            "translation",
+            "treat",
+            "trigger",
+            "trim",
+            "true",
+            "truncate",
+            "under",
+            "union",
+            "unique",
+            "unknown",
+            "unlink",
+            "unnest",
+            "until",
+            "update",
+            "usage",
+            "user",
+            "using",
+            "value",
+            "values",
+            "varchar",
+            "varchar2",
+            "varray",
+            "verify",
+            "view",
+            "when",
+            "whenever",
+            "where",
+            "while",
+            "window",
+            "with",
+            "within",
+            "without",
+            "work",
+            "year",
+            "yes",
+            "zone",
+        }
+
         def converttimezone_sql(self, expression: exp.ConvertTimezone) -> str:
             from_tz = expression.args.get("source_tz")
             to_tz = expression.args.get("target_tz")
@@ -558,9 +1033,3 @@ class Exasol(Dialect):
 
         def collate_sql(self, expression: exp.Collate) -> str:
             return self.sql(expression.this)
-
-        # https://docs.exasol.com/db/latest/sql_references/functions/alphabeticallistfunctions/rank.htm
-        def rank_sql(self, expression: exp.Rank) -> str:
-            if expression.args.get("expressions"):
-                self.unsupported("Exasol does not support arguments in RANK")
-            return self.func("RANK")
