@@ -5,6 +5,7 @@ import typing as t
 from sqlglot import exp, transforms
 from sqlglot.dialects.dialect import (
     binary_from_function,
+    bracket_to_element_at_sql,
     build_formatted_time,
     is_parse_json,
     pivot_column_names,
@@ -12,7 +13,7 @@ from sqlglot.dialects.dialect import (
     unit_to_str,
 )
 from sqlglot.dialects.hive import Hive
-from sqlglot.helper import seq_get
+from sqlglot.helper import ensure_list, seq_get
 from sqlglot.parser import build_trim
 from sqlglot.tokens import TokenType
 from sqlglot.transforms import (
@@ -148,6 +149,12 @@ class Spark2(Hive):
             "DAYOFWEEK": lambda args: exp.DayOfWeek(this=exp.TsOrDsToDate(this=seq_get(args, 0))),
             "DAYOFYEAR": lambda args: exp.DayOfYear(this=exp.TsOrDsToDate(this=seq_get(args, 0))),
             "DOUBLE": _build_as_cast("double"),
+            "ELEMENT_AT": lambda args: exp.Bracket(
+                this=seq_get(args, 0),
+                expressions=ensure_list(seq_get(args, 1)),
+                offset=1,
+                safe=False,
+            ),
             "FLOAT": _build_as_cast("float"),
             "FORMAT_STRING": exp.Format.from_arg_list,
             "FROM_UTC_TIMESTAMP": lambda args, dialect: exp.AtTimeZone(
@@ -200,8 +207,10 @@ class Spark2(Hive):
         }
 
         def _parse_drop_column(self) -> t.Optional[exp.Drop | exp.Command]:
-            return self._match_text_seq("DROP", "COLUMNS") and self.expression(
-                exp.Drop, this=self._parse_schema(), kind="COLUMNS"
+            return (
+                self.expression(exp.Drop, this=self._parse_schema(), kind="COLUMNS")
+                if self._match_text_seq("DROP", "COLUMNS")
+                else None
             )
 
         def _pivot_column_names(self, aggregations: t.List[exp.Expression]) -> t.List[str]:
@@ -345,3 +354,9 @@ class Spark2(Hive):
 
         def renamecolumn_sql(self, expression: exp.RenameColumn) -> str:
             return super(Hive.Generator, self).renamecolumn_sql(expression)
+
+        def bracket_sql(self, expression: exp.Bracket) -> str:
+            if expression.args.get("safe") is False:
+                return bracket_to_element_at_sql(self, expression)
+
+            return super().bracket_sql(expression)
