@@ -248,20 +248,6 @@ class TypeAnnotator(metaclass=_TypeAnnotator):
         elif prev_type and t.cast(exp.DataType, prev_type).this == exp.DataType.Type.NULL:
             self._null_expressions.pop(expression_id, None)
 
-        if (
-            isinstance(expression, exp.Column)
-            and expression.is_type(exp.DataType.Type.JSON)
-            and (dot_parts := expression.meta.get("dot_parts"))
-        ):
-            # JSON dot access is case sensitive across all dialects, so we need to undo the normalization.
-            i = iter(dot_parts)
-            parent = expression.parent
-            while isinstance(parent, exp.Dot):
-                parent.expression.set("this", exp.to_identifier(next(i), quoted=True))
-                parent = parent.parent
-
-            expression.meta.pop("dot_parts", None)
-
         return expression
 
     def annotate(self, expression: E, annotate_scope: bool = True) -> E:
@@ -434,6 +420,18 @@ class TypeAnnotator(metaclass=_TypeAnnotator):
                 else:
                     self._set_type(expr, exp.DataType.Type.UNKNOWN)
 
+                if expr.is_type(exp.DataType.Type.JSON) and (
+                    dot_parts := expr.meta.get("dot_parts")
+                ):
+                    # JSON dot access is case sensitive across all dialects, so we need to undo the normalization.
+                    i = iter(dot_parts)
+                    parent = expr.parent
+                    while isinstance(parent, exp.Dot):
+                        parent.expression.replace(exp.to_identifier(next(i), quoted=True))
+                        parent = parent.parent
+
+                    expr.meta.pop("dot_parts", None)
+
                 if expr.type and expr.type.args.get("nullable") is False:
                     expr.meta["nonnull"] = True
                 continue
