@@ -22,6 +22,8 @@ def canonicalize(expression: exp.Expression, dialect: DialectType = None) -> exp
     dialect = Dialect.get_or_raise(dialect)
 
     def _canonicalize(expression: exp.Expression) -> exp.Expression:
+        if not isinstance(expression, _CANONICALIZE_TYPES):
+            return expression
         expression = add_text_to_concat(expression)
         expression = replace_date_funcs(expression, dialect=dialect)
         expression = coerce_type(expression, dialect.PROMOTE_TO_INFERRED_DATETIME_TYPE)
@@ -33,9 +35,59 @@ def canonicalize(expression: exp.Expression, dialect: DialectType = None) -> exp
     return exp.replace_tree(expression, _canonicalize)
 
 
+COERCIBLE_DATE_OPS = (
+    exp.Add,
+    exp.Sub,
+    exp.EQ,
+    exp.NEQ,
+    exp.GT,
+    exp.GTE,
+    exp.LT,
+    exp.LTE,
+    exp.NullSafeEQ,
+    exp.NullSafeNEQ,
+)
+
+
+# All expression types that any of the canonicalize functions can act on
+_CANONICALIZE_TYPES = tuple(
+    {
+        # add_text_to_concat
+        exp.Add,
+        # replace_date_funcs
+        exp.Date,
+        exp.TsOrDsToDate,
+        exp.Timestamp,
+        # coerce_type (COERCIBLE_DATE_OPS + Between, Extract, DateAdd, DateSub, DateTrunc, DateDiff)
+        *COERCIBLE_DATE_OPS,
+        exp.Between,
+        exp.Extract,
+        exp.DateAdd,
+        exp.DateSub,
+        exp.DateTrunc,
+        exp.DateDiff,
+        # remove_redundant_casts
+        exp.Cast,
+        # ensure_bools (Connector, Not, If, Where, Having)
+        exp.Connector,
+        exp.Not,
+        exp.If,
+        exp.Where,
+        exp.Having,
+        # remove_ascending_order
+        exp.Ordered,
+    }
+)
+
+
 def add_text_to_concat(node: exp.Expression) -> exp.Expression:
     if isinstance(node, exp.Add) and node.type and node.type.this in exp.DataType.TEXT_TYPES:
-        node = exp.Concat(expressions=[node.left, node.right])
+        node = exp.Concat(
+            expressions=[node.left, node.right],
+            # All known dialects, i.e. Redshift and T-SQL, that support
+            # concatenating strings with the + operator do not coalesce NULLs.
+            coalesce=False,
+        )
     return node
 
 
@@ -58,26 +110,12 @@ def replace_date_funcs(node: exp.Expression, dialect: DialectType) -> exp.Expres
     return node
 
 
-COERCIBLE_DATE_OPS = (
-    exp.Add,
-    exp.Sub,
-    exp.EQ,
-    exp.NEQ,
-    exp.GT,
-    exp.GTE,
-    exp.LT,
-    exp.LTE,
-    exp.NullSafeEQ,
-    exp.NullSafeNEQ,
-)
-
-
 def coerce_type(node: exp.Expression, promote_to_inferred_datetime_type: bool) -> exp.Expression:
     if isinstance(node, COERCIBLE_DATE_OPS):
         _coerce_date(node.left, node.right, promote_to_inferred_datetime_type)
     elif isinstance(node, exp.Between):
         _coerce_date(node.this, node.args["low"], promote_to_inferred_datetime_type)
-    elif isinstance(node, exp.Extract) and not node.expression.type.is_type(
+    elif isinstance(node, exp.Extract) and not node.expression.is_type(
         *exp.DataType.TEMPORAL_TYPES
     ):
         _replace_cast(node.expression, exp.DataType.Type.DATETIME)
