@@ -9,9 +9,11 @@ EXPRESSION_METADATA = {
         expr_type: {"returns": exp.DataType.Type.BIGINT}
         for expr_type in {
             exp.BitLength,
+            exp.DateDiff,
             exp.Day,
             exp.DayOfMonth,
             exp.DayOfWeek,
+            exp.DayOfWeekIso,
             exp.DayOfYear,
             exp.Hour,
             exp.Length,
@@ -26,6 +28,7 @@ EXPRESSION_METADATA = {
     **{
         expr_type: {"returns": exp.DataType.Type.INT128}
         for expr_type in {
+            exp.CountIf,
             exp.Factorial,
         }
     },
@@ -33,10 +36,19 @@ EXPRESSION_METADATA = {
         expr_type: {"returns": exp.DataType.Type.DOUBLE}
         for expr_type in {
             exp.Atan2,
-            exp.Rand,
+            exp.JarowinklerSimilarity,
             exp.TimeToUnix,
         }
     },
+    **{
+        expr_type: {"returns": exp.DataType.Type.VARCHAR}
+        for expr_type in {
+            exp.Format,
+            exp.Reverse,
+        }
+    },
+    exp.DateBin: {"annotator": lambda self, e: self._annotate_by_args(e, "expression")},
+    exp.Localtimestamp: {"returns": exp.DataType.Type.TIMESTAMP},
     exp.ToDays: {"returns": exp.DataType.Type.INTERVAL},
     exp.TimeFromParts: {"returns": exp.DataType.Type.TIME},
 }
