@@ -22,10 +22,14 @@ EXPRESSION_METADATA = {
     **{
         expr_type: {"returns": exp.DataType.Type.VARCHAR}
         for expr_type in {
+            exp.AddMonths,
             exp.CurrentDatabase,
-            exp.CurrentSchema,
             exp.CurrentUser,
+            exp.CurrentSchema,
             exp.Hex,
+            exp.NextDay,
+            exp.Repeat,
+            exp.Replace,
             exp.Soundex,
         }
     },
@@ -43,8 +47,20 @@ EXPRESSION_METADATA = {
             exp.Second,
         }
     },
+    **{
+        expr_type: {"annotator": lambda self, e: self._annotate_by_args(e, "this")}
+        for expr_type in {
+            exp.ArrayDistinct,
+            exp.ArrayExcept,
+            exp.Reverse,
+        }
+    },
+    exp.ApproxQuantile: {"annotator": lambda self, e: self._annotate_by_args(e, "quantile")},
+    exp.ArrayIntersect: {"annotator": lambda self, e: self._annotate_by_args(e, "expressions")},
     exp.Coalesce: {
         "annotator": lambda self, e: self._annotate_by_args(e, "this", "expressions", promote=True)
     },
     exp.If: {"annotator": lambda self, e: self._annotate_by_args(e, "true", "false", promote=True)},
+    exp.Quantile: {"annotator": lambda self, e: self._annotate_by_args(e, "quantile")},
+    exp.RegexpSplit: {"returns": exp.DataType.build("ARRAY<STRING>")},
 }
