@@ -5,10 +5,22 @@ from sqlglot.typing import EXPRESSION_METADATA
 
 EXPRESSION_METADATA = {
     **EXPRESSION_METADATA,
+    **{
+        expr_type: {"returns": exp.DataType.Type.BIGINT}
+        for expr_type in {
+            exp.BitwiseAnd,
+            exp.BitwiseNot,
+            exp.BitwiseOr,
+            exp.BitwiseXor,
+            exp.Length,
+            exp.Levenshtein,
+            exp.StrPosition,
+            exp.WidthBucket,
+        }
+    },
     **{
         expr_type: {"annotator": lambda self, e: self._annotate_by_args(e, "this")}
         for expr_type in {
-            exp.Abs,
             exp.Ceil,
             exp.Floor,
             exp.Round,
@@ -21,4 +33,5 @@ EXPRESSION_METADATA = {
         if e.this
         else self._set_type(e, exp.DataType.Type.DOUBLE)
     },
+    exp.MD5Digest: {"returns": exp.DataType.Type.VARBINARY},
 }
