@@ -1,3 +1,4 @@
+from sqlglot import exp
 from tests.dialects.test_dialect import Validator
 
 
@@ -10,6 +11,22 @@ class TestExasol(Validator):
             "SELECT 1 AS [x]",
             'SELECT 1 AS "x"',
         )
+        self.validate_identity("SYSTIMESTAMP", "SYSTIMESTAMP()")
+        self.validate_identity("SELECT SYSTIMESTAMP()")
+        self.validate_identity("SELECT SYSTIMESTAMP(6)")
+        self.validate_identity("SELECT CURDATE()", "SELECT CURRENT_DATE")
+        self.validate_identity("SELECT USER", "SELECT CURRENT_USER")
+        self.validate_identity("SELECT USER()", "SELECT CURRENT_USER")
+        self.validate_identity("SELECT CURRENT_USER", "SELECT CURRENT_USER")
+        self.validate_identity("CURRENT_SCHEMA").assert_is(exp.CurrentSchema)
+        self.validate_identity("SELECT NOW()", "SELECT CURRENT_TIMESTAMP()")
+
+    def test_exasol_keywords(self):
+        keywords = ["CS", "ADD", "BOOLEAN", "CALL", "CONTROL"]
+
+        for keyword in keywords:
+            with self.subTest(keyword=keyword):
+                self.validate_identity(f"SELECT 1 AS {keyword}", f'SELECT 1 AS "{keyword}"')
 
     def test_qualify_unscoped_star(self):
         self.validate_all(
@@ -256,14 +273,16 @@ class TestExasol(Validator):
             },
         )
 
-        self.validate_all(
-            "SELECT a, b, rank(b) OVER (ORDER BY b) FROM (VALUES ('A1', 2), ('A1', 1), ('A2', 3), ('A1', 1)) AS tab(a, b)",
-            write={
-                "exasol": "SELECT a, b, RANK() OVER (ORDER BY b) FROM (VALUES ('A1', 2), ('A1', 1), ('A2', 3), ('A1', 1)) AS tab(a, b)",
-                "databricks": "SELECT a, b, RANK(b) OVER (ORDER BY b NULLS LAST) FROM VALUES ('A1', 2), ('A1', 1), ('A2', 3), ('A1', 1) AS tab(a, b)",
-                "spark": "SELECT a, b, RANK(b) OVER (ORDER BY b NULLS LAST) FROM VALUES ('A1', 2), ('A1', 1), ('A2', 3), ('A1', 1) AS tab(a, b)",
-            },
-        )
+        for func in ("RANK", "DENSE_RANK"):
+            with self.subTest(func=func):
+                self.validate_all(
+                    f"SELECT a, b, {func}(b) OVER (ORDER BY b) FROM (VALUES ('A1', 2), ('A1', 1), ('A2', 3), ('A1', 1)) AS tab(a, b)",
+                    write={
+                        "exasol": f"SELECT a, b, {func}() OVER (ORDER BY b) FROM (VALUES ('A1', 2), ('A1', 1), ('A2', 3), ('A1', 1)) AS tab(a, b)",
+                        "databricks": f"SELECT a, b, {func}(b) OVER (ORDER BY b NULLS LAST) FROM VALUES ('A1', 2), ('A1', 1), ('A2', 3), ('A1', 1) AS tab(a, b)",
+                        "spark": f"SELECT a, b, {func}(b) OVER (ORDER BY b NULLS LAST) FROM VALUES ('A1', 2), ('A1', 1), ('A2', 3), ('A1', 1) AS tab(a, b)",
+                    },
+                )
 
     def test_stringFunctions(self):
         self.validate_identity(
@@ -336,10 +355,10 @@ class TestExasol(Validator):
                 "SELECT TO_CHAR(CAST('1999-12-31' AS DATE)) AS TO_CHAR",
                 write={
                     "exasol": "SELECT TO_CHAR(CAST('1999-12-31' AS DATE)) AS TO_CHAR",
-                    "redshift": "SELECT TO_CHAR(CAST('1999-12-31' AS DATE)) AS TO_CHAR",
                     "presto": "SELECT DATE_FORMAT(CAST('1999-12-31' AS DATE)) AS TO_CHAR",
                     "oracle": "SELECT TO_CHAR(CAST('1999-12-31' AS DATE)) AS TO_CHAR",
-                    "postgres": "SELECT TO_CHAR(CAST('1999-12-31' AS DATE)) AS TO_CHAR",
+                    "redshift": "SELECT CAST(CAST('1999-12-31' AS DATE) AS VARCHAR(MAX)) AS TO_CHAR",
+                    "postgres": "SELECT CAST(CAST('1999-12-31' AS DATE) AS TEXT) AS TO_CHAR",
                 },
                 read={
                     "exasol": "SELECT TO_CHAR(DATE '1999-12-31') AS TO_CHAR",
@@ -423,6 +442,16 @@ class TestExasol(Validator):
                     f"SELECT TO_CHAR(CAST('2024-07-08 13:45:00' AS TIMESTAMP), '{fmt}') AS {alias}"
                 )
 
+        self.validate_all(
+            "SELECT TO_CHAR(CAST('2024-07-08 13:45:00' AS TIMESTAMP), 'DY')",
+            write={
+                "exasol": "SELECT TO_CHAR(CAST('2024-07-08 13:45:00' AS TIMESTAMP), 'DY')",
+                "oracle": "SELECT TO_CHAR(CAST('2024-07-08 13:45:00' AS TIMESTAMP), 'DY')",
+                "postgres": "SELECT TO_CHAR(CAST('2024-07-08 13:45:00' AS TIMESTAMP), 'TMDy')",
+                "databricks": "SELECT DATE_FORMAT(CAST('2024-07-08 13:45:00' AS TIMESTAMP), 'EEE')",
+            },
+        )
+
         self.validate_all(
             "TO_DATE(x, 'YYYY-MM-DD')",
             write={
@@ -481,7 +510,7 @@ class TestExasol(Validator):
         )
         units = ["MM", "QUARTER", "WEEK", "MINUTE", "YEAR"]
         for unit in units:
-            with self.subTest(f"Testing TO_CHAR with format '{unit}'"):
+            with self.subTest(f"Testing DATE_TRUNC with format '{unit}'"):
                 self.validate_all(
                     f"SELECT TRUNC(CAST('2006-12-31' AS DATE), '{unit}') AS TRUNC",
                     write={
@@ -572,6 +601,51 @@ class TestExasol(Validator):
         self.validate_identity("SELECT TRUNC(123.456, 2) AS TRUNC")
         self.validate_identity("SELECT DIV(1234, 2) AS DIV")
 
+        # Numeric truncation identity
+        self.validate_identity("TRUNC(123.456, 2)").assert_is(exp.Trunc)
+        self.validate_identity("TRUNC(3.14159)").assert_is(exp.Trunc)
+
+        # Date truncation with typed column and unit
+        # (parse_one because DateTrunc generates as DATE_TRUNC, not TRUNC)
+        self.parse_one("TRUNC(CAST(x AS DATE), 'MONTH')").assert_is(exp.DateTrunc)
+        self.parse_one("TRUNC(CAST(x AS TIMESTAMP), 'MONTH')").assert_is(exp.DateTrunc)
+        self.parse_one("TRUNC(CAST(x AS DATETIME), 'MONTH')").assert_is(exp.DateTrunc)
+
+        # Fallback to Anonymous (Exasol requires unit for date truncation)
+        self.validate_identity("TRUNC(CAST(x AS DATE))").assert_is(exp.Anonymous)
+
+        # Cross-dialect numeric truncation transpilation
+        self.validate_all(
+            "TRUNC(price, 2)",
+            write={
+                "exasol": "TRUNC(price, 2)",
+                "oracle": "TRUNC(price, 2)",
+                "postgres": "TRUNC(price, 2)",
+                "mysql": "TRUNCATE(price, 2)",
+                "tsql": "ROUND(price, 2, 1)",
+            },
+        )
+
+        # Date truncation with various units (Exasol-specific unit names)
+        for unit in ("YYYY", "MM", "DD", "HH", "MI", "SS", "WW"):
+            with self.subTest(f"Date/time TRUNC with {unit}"):
+                self.validate_all(
+                    f"TRUNC(CAST(x AS TIMESTAMP), '{unit}')",
+                    write={
+                        "exasol": f"DATE_TRUNC('{unit}', x)",
+                        "oracle": f"TRUNC(CAST(x AS TIMESTAMP), '{unit}')",
+                    },
+                )
+
+        # Q gets normalized to QUARTER
+        self.validate_all(
+            "TRUNC(CAST(x AS TIMESTAMP), 'Q')",
+            write={
+                "exasol": "DATE_TRUNC('QUARTER', x)",
+                "oracle": "TRUNC(CAST(x AS TIMESTAMP), 'QUARTER')",
+            },
+        )
+
     def test_scalar(self):
         self.validate_all(
             "SELECT CURRENT_USER",
@@ -705,6 +779,8 @@ class TestExasol(Validator):
             "SELECT name, age, IF age < 18 THEN 'underaged' ELSE 'adult' ENDIF AS LEGALITY FROM persons"
         )
 
+        self.validate_identity("SELECT HASHTYPE_MD5(a, b, c, d)")
+
     def test_odbc_date_literals(self):
         self.validate_identity("SELECT {d'2024-01-01'}", "SELECT TO_DATE('2024-01-01')")
         self.validate_identity(
@@ -762,3 +838,13 @@ class TestExasol(Validator):
                     exasol_sql,
                     write={"exasol": exasol_sql, "databricks": dbx_sql},
                 )
+
+    def test_json(self):
+        self.validate_identity("""SELECT JSON_VALUE('{"d":"a"}', '$.d' NULL ON ERROR) AS x""")
+        self.validate_all(
+            """SELECT JSON_VALUE('{"d":"a"}', '$.d' NULL ON ERROR) AS x""",
+            write={
+                "exasol": """SELECT JSON_VALUE('{"d":"a"}', '$.d' NULL ON ERROR) AS x""",
+                "trino": """SELECT JSON_VALUE('{"d":"a"}', '$.d' NULL ON ERROR) AS x""",
+            },
+        )
