@@ -24,6 +24,8 @@ class TestSingleStore(Validator):
         self.validate_identity("SELECT TO_JSON(ROW(1, 2) :> RECORD(a INT, b INT))")
 
         self.validate_identity("JSON_KEYS(json_doc, 'a', 'b', 'c', 2)")
+        self.validate_identity("SELECT VERSION()")
+        self.validate_identity("SELECT CURTIME()", "SELECT CURRENT_TIME()")
 
     def test_byte_strings(self):
         self.validate_identity("SELECT e'text'")
