@@ -246,7 +246,7 @@ SELECT AGGREGATE(a, (a, b) -> a + b) AS x
 SELECT COUNT(DISTINCT a, b)
 SELECT COUNT(DISTINCT a, b + 1)
 SELECT SUM(DISTINCT x)
-SELECT TRUNCATE(a, b)
+SELECT TRUNC(a, b)
 SELECT ARRAY_AGG(STRUCT(x, x AS y) ORDER BY z DESC) AS x
 SELECT LAG(x) OVER (ORDER BY y) AS x
 SELECT LEAD(a) OVER (ORDER BY b) AS a
@@ -871,7 +871,7 @@ SELECT values
 SELECT values AS values FROM t WHERE values + 1 > 3
 SELECT truncate
 SELECT only
-TRUNCATE(a, b)
+TRUNC(a, b)
 SELECT enum
 SELECT unlogged
 SELECT name
